@@ -1,21 +1,17 @@
 package Test::BDD::Cucumber::StepFile;
-{
-  $Test::BDD::Cucumber::StepFile::VERSION = '0.16';
-}
-
+$Test::BDD::Cucumber::StepFile::VERSION = '0.18';
 =head1 NAME
 
 Test::BDD::Cucumber::StepFile - Functions for creating and loading Step Definitions
 
 =head1 VERSION
 
-version 0.16
+version 0.18
 
 =cut
 
 use strict;
 use warnings;
-use File::Find;
 
 require Exporter;
 our @ISA = qw(Exporter);
